<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\ImageController;
use App\Http\Controllers\SocialMediaController;
use App\Http\Requests\Admin\AdminChangeStatusRequest;
use App\Http\Resources\ShowProfileResource;
use App\Models\Company;
use App\Models\SocialMediable;
use App\Models\User;
use App\Repositories\JobTitleRepository;
use App\Repositories\Role\SettingInformationRepository;
use App\Services\AddressService;
use App\Services\OwnerService;
use App\Traits\ApiResponser;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Symfony\Component\HttpFoundation\Response;

class ClientController extends Controller
{
    use ApiResponser;

    public $clientType;
    public $clientEntity;
    public $clientId;
    public $client;

    public function __construct()
    {
        $this->middleware(['auth:sanctum', 'isAdmin']);

        $this->middleware('can:edit-company')->only(['changeStatusCompany']);
        $this->middleware('can:edit-company')->only(['changeStatusCompany']);
        $this->middleware('can:edit-users')->only(['changeStatusUser']);
        $this->middleware('can:edit-users')->only(['updateUser']);
        $this->middleware('can:delete-users')->only(['deleteUser']);
        $this->middleware('can:delete-company')->only(['deleteCompany']);

    }

    public function changeStatusCompany(AdminChangeStatusRequest $request)
    {
//        return 10;
//        return $request->status;
        $clint = Company::find($request->id);
        if ($clint) {
            $clint->update(['status' => $request->status]);
            return $this->successResponseWithoutMessage(true, $clint);
        } else {
            return $this->failedResponse('No information found');
        }
    }

    public function changeStatusUser(AdminChangeStatusRequest $request)
    {
        $clint = User::find($request->id);
        if ($clint) {
            $clint->update(['status' => $request->status]);
            return $this->successResponseWithoutMessage(true, $clint);
        } else {
            return $this->failedResponse('No information found');
        }
    }

    public function updateUser(Request $request,$id)
    {
//        return 1;
//        return $this->request->image;
//        Log::info($this->request);
        //validate data
        if (!(User::find($id)))
            return $this->onFaile('user not found');
        $validatedData = $request->validate([
            'first_name' => ['required', 'regex:/^[a-zA-Z\s]+$/', 'max:100', 'min:3'],
            'last_name' => ['required', 'regex:/^[a-zA-Z\s]+$/', 'max:100', 'min:3'],
            'image' => 'image|mimes:jpg,png,jpeg,gif,svg|max:2048',
            'phone_number' => ['max:20', 'min:3'],
            'email' => [ 'email'],
            'work_experience' => [ 'min:2'],
            'job_title' => [ 'exists:job_titles,title','max:30', 'min:3'],
            'about_us' => 'max:600',
            'social_media.*' => ['array'],
            'social_media.*.review' => ['nullable','between:1,10'],
            'social_media.*.link' => ['required_with:social_media.*.review', 'min:1']
        ]);
        if (isset($request['social_media'])) {

            $media = new SocialMediaController();
            $media->storeSocialMedia($id, User::class, $request['social_media']);
        }
        //add image
        $imageName = null;
        if ($request['image']) {
            $imageController = new ImageController();
            $imageName = $imageController->upload($request->image);
        }
//return $imageName ;
        //add job
        $jobId = null;
        if (isset($request['job_title'])) {
            $jobRepository = new JobTitleRepository();
            $job = $jobRepository->findJob($request['job_title']);
            if ($job == null) {
                return failedResponse('Not Found job', Response::HTTP_OK);
            }
            $jobId = $job->toArray()['id'];
        }
        $settingInformationRepository = new SettingInformationRepository();

        $user = $settingInformationRepository->updateInformationUser($request, $id, $jobId, $imageName);
        $return= User::find( $id);
//        return $return;
            if ($return) {
                $return->load(['jobTitle']);
                $social = SocialMediable::query()->with('SocialMedia')
                    ->where('social_mediable_type', User::class)
                    ->where('social_mediable_id', $id)->get();
                $return['social'] = ShowProfileResource::collection($social);
            }
        return successResponse(true, $return, 'send successfully');    }

    public function createUser(Request $request)
    {
//        return 1;
//        return $this->request->image;
//        Log::info($this->request);
        //validate data

        $validatedData = $request->validate([
            'first_name' => ['required', 'max:100', 'min:3'],
            'last_name' => ['required', 'max:100', 'min:3'],
            'image' => 'image|mimes:jpg,png,jpeg,gif,svg|max:2048',
            'phone_number' => ['max:20', 'min:3'],
            'email' => [ 'email',Rule::unique('users', 'email')->whereNull('deleted_at')],
            'work_experience' => [ 'min:2'],
            'password' => [ 'required','min:6'],
            'job_title' => [ 'exists:job_titles,title','max:30', 'min:3'],
            'about_us' => 'max:600',
            'social_media.*' => ['array'],
            'social_media.*.review' => ['nullable','between:1,10'],
            'social_media.*.link' => ['required_with:social_media.*.review', 'min:1']
        ]);

        //add image
        $imageName = null;
        if ($request['image']) {
            $imageController = new ImageController();
            $imageName = $imageController->upload($request->image);
        }
//return $imageName ;
        //add job
        $jobId = null;
        if (isset($request['job_title'])) {
            $jobRepository = new JobTitleRepository();
            $job = $jobRepository->findJob($request['job_title']);
            if ($job == null) {
                return failedResponse('Not Found job', Response::HTTP_OK);
            }
            $jobId = $job->toArray()['id'];
        }
        $settingInformationRepository = new SettingInformationRepository();
//        return [$request,$jobId,$imageName];

        $user = $settingInformationRepository->createUser($request, $jobId, $imageName);
        $return= User::find( $user->id);
//        return $user;
        if ($return) {
            if (isset($request['social_media'])) {

            $media = new SocialMediaController();
            $media->storeSocialMedia($user->id, User::class, $request['social_media']);
        }
            $return->load(['jobTitle']);
            $social = SocialMediable::query()->with('SocialMedia')
                ->where('social_mediable_type', User::class)
                ->where('social_mediable_id', $user->id)->get();
            $return['social'] = ShowProfileResource::collection($social);
        }

        return successResponse(true, $return, 'send successfully');    }

    public function deleteUser($name)
    {
//        return $name;
        $user = User::find($name);
        if ($user)
            $user->delete();
        return ($user) ? $this->onSuccess(null) : $this->onFaile('User not found');
    }


    public function deleteUseremail($name)
    {
        $user = User::where('email', $name)->first();
        $user->forceDelete();
//        User::where('email',$name)->first()->forceDelete();
        return ($user) ? $this->onSuccess('ok') : $this->onFaile('delete user');
    }

    public function updateCompany(Request $request,$id)
    {
//        $this->setInformation();
        //validate
        $validateData = $request->validate([
            'name' => ['required', 'max:255', 'min:3',
                Rule::unique('companies', 'name')->ignore($id)],
            'image' => ['image', 'mimes:jpg,png,jpeg,gif,svg', 'max:2048'],
            'company_phone_number' => ['max:20', 'min:3'],
            'about_us' => 'max:600',
            'country' => ['required', 'min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'city' => ['required', 'min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'state' => ['required', 'min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'job_title' => ['regex:/^[a-zA-Z\s]+$/', 'max:30', 'min:3'],
            'zip_code' => ['required', 'numeric', 'digits_between:1,20'],
            'main_text' => ['min:2', 'max:200'],
            'secondary_text' => ['min:2', 'max:200'],
            'social_media.*.*' => ['min:3', 'max:200'],
            'owner.first_name' => ['required', 'size:1'],
            'owner.last_name' => ['required', 'regex:/^[a-zA-Z\s]+$/', 'min:2', 'max:40'],
            'owner.email' => ['required', 'email'],
            'owner.phone_number' => ['required', 'max:20', 'min:3'],
            'social_media.*' => ['array'],
            'social_media.*.review' => ['between:1,10'],
            'social_media.*.link' => ['required_with:social_media.*.review', 'min:1'],
            'owner.address.*' => ['array'],
            'owner.address.main_text' => ['min:3', 'max:50', 'max:250'],
            'owner.address.secondary_text' => ['min:3', 'max:50', 'max:250'],
            'owner.address.country' => ['min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'owner.address.city' => ['min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'owner.address.state' => ['min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'owner.address.zip_code' => ['digits_between:1,20', 'numeric']
        ]);
        if (!Company::find($id)){
            return $this->onFaile('company not found');
        }
        //add image
        $imageName = null;
        if (array_key_exists('image', $validateData)) {
            $imageController = new ImageController();
            $imageName = $imageController->upload($request->image);
        }
        //add social media
        if (array_key_exists('social_media', $validateData)) {
//            return  1;
            $media = new SocialMediaController();
            $media = $media->storeSocialMedia($id,Company::class, $request['social_media']);
            if ($media == 0)
                return $this->failedResponse('not found social media', Response::HTTP_NOT_FOUND);
        }
//        return 1;

        //add address
        $addressService = new AddressService;
        $address = $addressService->checkExist(Company::class, $id);
        if ($address != null) {
            $addressUpdate = $addressService->update($validateData, $address->id);
        } else {
            $addressStore = $addressService->store($validateData,Company::class, $id);
        }

        //add owner
        if (array_key_exists('owner', $validateData)) {
            $ownerService = new OwnerService();
            $service = $ownerService->checkExists(Company::class, $id);
            if ($service == null)
                $owner = $ownerService->store($validateData['owner'], Company::class, $id);
            else {
                $owner = $ownerService->update($validateData['owner'], $service->id);
            }
        }

        //add job
        $jobId = null;
        if (array_key_exists('job_title', $validateData)) {
            $jobRepository = new JobTitleRepository();
            $job = $jobRepository->findJob($request['job_title']);
            if ($job == null) {
                return failedResponse('Not Found job', Response::HTTP_OK);
            }
            $jobId = $job->toArray()['id'];
        }

        //add information user
        $settingInformationRepository = new SettingInformationRepository();
        $company = $settingInformationRepository->updateInformationCompany($request, $id, $imageName, $jobId);

//        $this->clientEntity = auth($clientRole)->user();
//        $list = $this->clientEntity->load(['socialMedias', 'jobTitle']);
        if ($company) {
            $return = Company::find($id)->load(['jobTitle', 'address', 'owner']);
            $social = SocialMediable::query()->with('SocialMedia')->where('social_mediable_type', $this->clientType)->where('social_mediable_id', $this->clientId)->get();

            $return['social'] = ShowProfileResource::collection($social);
        }
        return ($company)? successResponse(true, $return, 'send successfully'):$this->onFaile(''); }
    public function CreateCompany(Request $request)
    {
//        $this->setInformation();
        //validate
//$this->setInformation()
        $validateData = $request->validate([
            'name' => ['required', 'max:255', 'min:3',
                Rule::unique('companies', 'name')->ignore($this->clientId)],
            'image' => ['image', 'mimes:jpg,png,jpeg,gif,svg', 'max:2048'],
            'company_phone_number' => ['required','max:20', 'min:3'],
            'about_us' => ['max:600'],
            'country' => [ 'min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'city' => [ 'min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'state' => [ 'min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'job_title' => ['required', 'max:30'],
            'zip_code' => [ 'numeric', 'digits_between:1,20'],
            'main_text' => ['min:2', 'max:200'],
            'secondary_text' => ['min:2', 'max:200'],
            'social_media.*.*' => [ 'max:200'],
            'owner.first_name' => ['size:1'],
            'owner.last_name' => [ 'regex:/^[a-zA-Z\s]+$/', 'min:2', 'max:40'],
            'owner.company_name' => [ 'regex:/^[a-zA-Z\s]+$/', 'min:2', 'max:40'],
            'owner.email' => [ 'email'],
            'owner.phone_number' => ['max:20', 'min:3'],
            'social_media.*' => ['array'],
            'social_media.*.review' => ['between:1,10'],
            'social_media.*.link' => ['required_with:social_media.*.review'],
            'owner.address.*' => ['array'],
            'owner.address.main_text' => ['min:3', 'max:50', 'max:250'],
            'owner.address.secondary_text' => ['min:3', 'max:50', 'max:250'],
            'owner.address.country' => ['min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'owner.address.city' => ['min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'owner.address.state' => ['min:2', 'max:50', 'regex:/^[a-zA-Z\s]+$/'],
            'owner.address.zip_code' => ['digits_between:1,20', 'numeric']
        ]);
//                return 22;

        //add image
        $imageName = null;
        if (array_key_exists('image', $validateData)) {
            $imageController = new ImageController();
            $imageName = $imageController->upload($this->request->image);
        }
        //add social media

//        return 1;

        //add address
        $addressService = new AddressService;
        $address = $addressService->checkExist($this->clientType, $this->clientId);
        if ($address != null) {
            $addressUpdate = $addressService->update($validateData, $address->id);
        } else {
            $addressStore = $addressService->store($validateData, $this->clientType, $this->clientId);
        }

        //add owner
        if (array_key_exists('owner', $validateData)) {
            $ownerService = new OwnerService();
            $service = $ownerService->checkExists(Company::class, $this->clientId);
            if ($service == null)
                $owner = $ownerService->store($validateData['owner'], $this->clientType, $this->clientId);
            else {
                $owner = $ownerService->update($validateData['owner'], $service->id);
            }
        }
//        return 1;

        //add job
        $jobId = null;
        if (array_key_exists('job_title', $validateData)) {
            $jobRepository = new JobTitleRepository();
            $job = $jobRepository->findJob($this->request['job_title']);
            if ($job == null) {
                return failedResponse('Not Found job', Response::HTTP_NOT_FOUND);
            }
            $jobId = $job->toArray()['id'];
        }
//        return 1;

        //add information user
        $settingInformationRepository = new SettingInformationRepository();
        $company = $settingInformationRepository->updateInformationCompany($this->request, $this->clientId,
            $imageName, $jobId);
        if (array_key_exists('social_media', $validateData)) {
            $media = new SocialMediaController();
//            return 1;

            $media = $media->storeSocialMedia($this->clientId, $this->clientType,$validateData['social_media']);

            if ($media == 0)
                return $this->failedResponse('not found social media', Response::HTTP_NOT_FOUND);
        }
//        $this->clientEntity = auth($clientRole)->user();
//        $list = $this->clientEntity->load(['socialMedias', 'jobTitle']);
        $return=  $this->clientEntity::find( $this->clientId)->load(['jobTitle','address','owner']) ;
        $social= SocialMediable::query()->with('SocialMedia')->where('social_mediable_type',$this->clientType)->where('social_mediable_id',$this->clientId)->get();

        $return['social']=ShowProfileResource::collection($social);
        return successResponse(true, $return, 'send successfully');
//        return ($company)? successResponse(true, $return, 'send successfully'):$this->onFaile('');
 }

    public function deleteCompany($name)
    {
        $company = Company::find($name);
        if ($company)
            $company->delete();
        return ($company) ? $this->onSuccess('') : $this->onFaile('company not found');
    }


    public function deleteCompanemaily($name)
    {
        $company = Company::where('email', $name)->first()->forcedelete();
        return ($company) ? $this->onSuccess('ok') : $this->onFaile('delete user');
    }
    public function setInformation($clientRole)
    {
        $this->clientType = 'App\\Models\\' . Str::ucfirst($clientRole);
        $this->clientEntity = auth($clientRole)->user();
        $this->clientId = $this->clientEntity->id;
        $this->client = $this->clientType::find($this->clientId);
        return 1;
    }


}
