<?php

namespace App\Repositories\Role;

use App\Models\Company;
use App\Models\User;
use App\Services\CodeService;
use Illuminate\Support\Facades\Hash;
use JasonGuru\LaravelMakeRepository\Repository\BaseRepository;

//use Your Model

/**
 * Class SettingInformationRepository.
 */
class SettingInformationRepository extends BaseRepository
{
    /**
     * @return string
     *  Return the model
     */
    public function model()
    {
        return User::class;
    }

    public function updateInformationCompany($request, $id, $image, $jobId)
    {
        return Company::where('id', $id)->update([
            'phone_number' => $request['company_phone_number'],
            'name' => $request['name'],
            'job_title_id' => $jobId,
            'about_us' => $request['about_us'],
            'image' => $image,
            'status' => 'confirmed'
        ]);
    }

    public function updateInformationUser($request, $id, $jobTitleId, $image)
    {
        return User::where('id', $id)->update([
            'name' => $request['first_name']??null,
            'last_name' => $request['last_name']??null,
            'phone_number' => $request['phone_number']??null,
//            'email' =>$request['email']??null,
            'work_experience' => $request['work_experience']??null,
            'about_us' => $request['about_us']??null,
            'job_title_id' => $jobTitleId??null,
            'image' => $image??null,
            'status' => 'confirmed'
        ]);
    }
    public function createUser($request, $jobTitleId, $image)
    {
//        return $request;
        return User::create([
            'name' => $request['first_name']??null,
            'last_name' => $request['last_name']??null,
            'phone_number' => $request['phone_number']??null,
            'email' =>$request['email']??null,
            'work_experience' => $request['work_experience']??null,
            'about_us' => $request['about_us']??null,
            'password' => Hash::make($request['password'])??null,
            'referral_code' => $this->makeCode(User::class),
            'job_title_id' => $jobTitleId??null,
            'image' => $image??null,
            'status' => 'confirmed'
        ]);
    }

    public function completeInformationCompany($request, $id, $jobTitleId)
    {
        return Company::where('id', $id)->update([
            'name' => $request['name'],
            'phone_number' => $request['phone_number'],
            'job_title_id' => $jobTitleId,
            'status' => 'confirmed'
        ]);
    }

    public function CompleteInformationUser($request, $id)
    {
        return User::where('id', $id)->update([
            'name' => $request['first_name'],
            'last_name' => $request['last_name'],
            'phone_number' => $request['phone_number'],
            'status' => 'confirmed'
        ]);
    }

    public function countUser()
    {
        return User::count();
    }

    public function countCompany()
    {
        return Company::count();
    }
    public function makeCode($clientRoles)
    {
        $codeService=new  CodeService ();
        do {
            $referralCode = $codeService->generateCode();
        } while ($codeService->check($clientRoles, 'referral_code', $referralCode));
        return $referralCode;
    }
}
