<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Admin\Services\AdminService;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\MangeAdmin\CreateAdminRequest;
use App\Http\Requests\Admin\MangeAdmin\UpdateAdminRequest;
use App\Traits\ApiResponser;
use App\Traits\Helper;
use App\Traits\pipeline;
use Illuminate\Http\Request;

class AdminController extends Controller
{
    use ApiResponser,Helper;
    public function __construct()
    {
        $this->middleware(['auth:sanctum','isAdmin']);

        $this->middleware('can:read-admin')->only(['allAdmins','showAdmin']);
        $this->middleware('can:create-admin')->only(['createAdmin']);
        $this->middleware('can:edit-admin')->only(['updateAdmin']);
        $this->middleware('can:delete-admin')->only('deleteAdmin');
    }
//    public function list(){
//        $admin=Admin::with('role')->get();
//        return ($admin)?$this->successResponseWithoutMessage(true,ListAdminResource::collection($admin))
//            :$this->successResponseWithoutMessage(true,[]);
//    }


    public function allAdmins(Request $request,AdminService $service)
    {
        $userId=$request->user()->id;
        $admins=$service->all($userId);
        if ($admins){
            return response()->json(['success'=>true,'data'=>$admins]);
        }
        else{
            return response()->json(['success'=>true,'data'=>[]]);
        }
    }

    /**
     * @param CreateAdminRequest $request
     * @param AdminService $service
     * @return \Illuminate\Http\JsonResponse
     */
    public function createAdmin(CreateAdminRequest $request, AdminService $service)
    {
        $admin=$service->create($request);
        if ( $admin){
            return response()->json(['success'=>true,'data'=>['admin'=>$admin]]);
        }
        else{
            return  response()->json(['success'=>false,'message'=>'خطا!لطفا دوباره امتحان کنید']);
        }
    }
    public function updateAdmin(UpdateAdminRequest $request,$adminId,AdminService $service)
    {
        $admin=$service->update($request->validated(),$adminId);
//        return $admin;
        if ($admin['success']== true){
            return response()->json(['success'=>true,'data'=>['admin'=>$admin['admin']]]);
        }
        else{
            return response()->json(['success'=>false,'message'=>$admin['message']]);

        }
    }
    public function showAdmin($adminId,AdminService $service)
    {
        $admin=$service->show($adminId);
        if ($admin['success']== true){
            return response()->json(['success'=>true,'data'=>['admin'=>$admin['admin']]]);
        }
        else{
            return response()->json(['success'=>false,'message'=>$admin['message']]);

        }
    }
    public function deleteAdmin($adminId,AdminService $service)
    {
        $admin=$service->delete($adminId);
        if ($admin['success']== true){
            return response()->json(['success'=>true]);
        }
        else{
            return response()->json(['success'=>false,'message'=>$admin['message']]);

        }
    }



}
