<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Comment extends Model
{
    use HasFactory;
    protected $table = 'comments';
    const PENDING_STATUS='pending';
    const COMPLETED_STATUS='confirmed';
    protected $guarded =[
        'id'
    ];

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    /**
     * The has Many Relationship
     *
     * @var array
     */
    /*public function replies()
    {
        return $this->hasMany(Comment::class, 'parent_id');
    }*/

    public function parent()
    {
        return $this->belongsTo(Comment::class, 'parent_id');
    }

    public function replies()
    {
        return $this->hasMany(Comment::class, 'parent_id', 'id');
    }

    public function allRepliesWithOwner()
    {
        return $this->replies()->with(__FUNCTION__, 'owner');
    }

    public function owner()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    //comment by user and company

    public function client()
    {
        return $this->morphTo('client');
    }

    //comment for user & company & project
    public function profile()
    {
        return $this->morphTo('profile');
    }
    public function profileComment()
    {
        return $this->belongsTo(ParticipantsProject::class,'project_id','project_id');
    }
    public function project()
    {
        return $this->belongsTo(Project::class,'project_id','id');
    }

//    public function rates()
//    {
//        return $this->morphOne(Rate::class, 'rateable','rateable_type','rateable_id');
//    }


}
