<?php

use App\Http\Controllers\AddressController;
use App\Http\Controllers\Admin\ClientController;
use App\Http\Controllers\Admin\Structure\FAQController;
use App\Http\Controllers\ChatController;
use App\Http\Controllers\ClaimController;
use App\Http\Controllers\Client\AuthenticationController;
use App\Http\Controllers\Client\ForgotPasswordController;
use App\Http\Controllers\Client\ProfileController;
use App\Http\Controllers\CommentController;
use App\Http\Controllers\CustomerController;
use App\Http\Controllers\EmailController;
use App\Http\Controllers\EstimateController;
use App\Http\Controllers\GalleryController;
use App\Http\Controllers\GeneralContractorController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\ImageController;
use App\Http\Controllers\InviteController;
use App\Http\Controllers\InvoiceController;
use App\Http\Controllers\JobController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\PaymentController;
use App\Http\Controllers\PDFController;
use App\Http\Controllers\ProjectController;
use App\Http\Controllers\ReferralCodeController;
use App\Http\Controllers\ReportController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/


Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

//Route::post('hsag', [ImageController::class, 'changePassword']);
Route::post('delete', [\App\Http\Controllers\frontController::class, 'delete']);
Route::post('addTemp', [ImageController::class, 'uploadTemp']);
Route::get('industry', [JobController::class, 'industry']);
Route::get('industry-app', [JobController::class, 'industryPaginate']);
Route::get('industry-photo', [JobController::class, 'industryPhoto']);
Route::get('footer', [HomeController::class, 'footer']);
Route::get('home', [HomeController::class, 'home']);
Route::post('confirmEmail', [EmailController::class, 'sendEmailConfirmation']);
Route::get('home/search', [HomeController::class, 'searchHome']);
Route::get('home/app/search', [HomeController::class, 'searchHomeForApp']);
Route::get('about-us', [HomeController::class, 'aboutUs']);
Route::get('support', [HomeController::class, 'support']);
Route::get('terms', [HomeController::class, 'Terms']);
Route::get('Project/{id}', [ProjectController::class, 'findProject']);
Route::get('country', [\App\Http\Controllers\MapController::class, 'country']);
Route::get('city/{id}', [\App\Http\Controllers\MapController::class, 'citys']);
Route::get('state/{id}', [\App\Http\Controllers\MapController::class, 'state']);
Route::get('app/country', [\App\Http\Controllers\MapController::class, 'countryForApp']);
Route::get('app/city/{id}', [\App\Http\Controllers\MapController::class, 'cityForApp']);
Route::get('app/state/{id}', [\App\Http\Controllers\MapController::class, 'stateForApp']);
Route::get('app/style', [\App\Http\Controllers\StyleControlller::class, 'indexForApp']);
Route::get('style', [\App\Http\Controllers\StyleControlller::class, 'index']);

Route::prefix('{clientRole}')->group(function () {
    Route::post('register', [AuthenticationController::class, 'register']);
    Route::post('checkotp', [AuthenticationController::class, 'checkOtp']);
    Route::post('login', [AuthenticationController::class, 'login']);
    Route::post('logout', [AuthenticationController::class, 'logout']);

    //complete profile
    Route::middleware('client')->group(function () {

        Route::post('/changePassword', [\App\Http\Controllers\User\UserController::class, 'changePassword']);
        Route::post('/completeInformation', [ProfileController::class, 'call'])->name('completeInformation');
        Route::get('/showInformation', [ProfileController::class, 'call'])->name('showInformation');
        Route::post('/updateInformation', [ProfileController::class, 'call'])->name('updateInformation');
        Route::get('/showInformationCompany', [ProfileController::class, 'showInformationCompany'])->name('showInformation');
        Route::get('/list-projects', [ProjectController::class, 'listProjects'])->name('list.project.name');
        Route::post('invite', [InviteController::class, 'store']);

        Route::post('gallery/details/client',[GalleryController::class,'showDetailsForUser']);
        Route::get('gallery',[GalleryController::class,'showForUser']);

        Route::get('Projects',[ProjectController::class,'showAllProject']);
        Route::post('Projects/{id}',[ProjectController::class,'UpdateProject']);
        Route::delete('Projects/photo/{id}', [\App\Http\Controllers\ProjectController::class, 'deletePhotoToProject']);
//        Route::get('Projects/add-member/{id}', [\App\Http\Controllers\ProjectController::class, 'showAddClient']);
        Route::get('Projects/add-member/{id}', [\App\Http\Controllers\ProjectController::class, 'showAddClient']);
        Route::post('Projects/add-member/{id}', [\App\Http\Controllers\ProjectController::class, 'addClient']);

//        Route::post('invite', function (){
//            dd(config('global.condition'));
//        });




        //Notification
        Route::get('notification',[NotificationController::class,'getMessagesNotification']);
        Route::put('notification/{id}',[NotificationController::class,'readNotify']);


        //get referral code
        Route::get('showReferralCode', [ReferralCodeController::class, 'show']);


        //chat
        Route::post('sendMessage', [ChatController::class, 'sendMessage']);
        Route::post('/groups/message', [ChatController::class, 'sendGroupMessage']);
        Route::post('sendMessagePrivet', [ChatController::class, 'sendPriavteMessage']);
        Route::get('getChats/{uuid}', [ChatController::class, 'getPrivateChats']);
        Route::get('getChatsGroup/{uuid}', [ChatController::class, 'getChatsGroup']);
        Route::get('getPrivateMessages', [ChatController::class, 'getPrivateMessages']);
        Route::post('createGroup',[ChatController::class,'createGroup']);
        Route::post('chats',[ChatController::class,'getGroupMember']);
        Route::get('groups',[ChatController::class,'getGroup']);
        Route::post('add-member',[ChatController::class,'addMember']);

        //Tag
        Route::post('tag',[\App\Http\Controllers\TagsController::class,'store']);
        Route::get('tag',[\App\Http\Controllers\TagsController::class,'index']);
        Route::get('tag/exists-read',[\App\Http\Controllers\TagsController::class,'existsRead']);
//        Route::get('red',[\App\Http\Controllers\TagsController::class,'index']);



        Route::post('getAddress', [AddressController::class, 'getAddress']);


        //estimate
        Route::post('addCustomer', [CustomerController::class, 'add']);
        Route::delete('deleteCustomer/{id}', [CustomerController::class, 'delete']);
        Route::post('addEstimate', [EstimateController::class, 'store']);
        Route::get('showEstimate/{id}', [EstimateController::class, 'show']);
        Route::get('showEstimate', [EstimateController::class, 'showList']);
        Route::delete('deleteEstimate/{id}', [EstimateController::class, 'delete']);
        Route::post('addNoteEstimate/{id}', [EstimateController::class, 'addNote']);
        Route::post('estimate/send-Email/{id}', [EstimateController::class, 'sendEmailEstimate']);
        Route::get('estimate/showMap', [EstimateController::class, 'showMapEstimate']);

        //Invoice
        Route::post('addInvoice', [InvoiceController::class, 'store']);
        Route::get('showInvoice/{id}', [InvoiceController::class, 'show']);
        Route::get('showInvoice', [InvoiceController::class, 'showList']);
        Route::delete('deleteInvoice/{id}', [InvoiceController::class, 'delete']);
        Route::post('addNoteInvoice/{id}', [InvoiceController::class, 'addNote']);


        //add comment
        Route::post('comment/store', [CommentController::class, 'store']);

        Route::post('storeJob', [JobController::class, 'store']);


        //profile
        Route::get('show-company/{id}', [ProfileController::class, 'showInformationCompanyForOthers']);
        Route::post('claim', [ClaimController::class, 'store']);


    });




    Route::post('reports/store', [ReportController::class, 'store']);
    Route::get('reports/showAll', [ReportController::class, 'showAll']);
    Route::get('reports/show/{id}', [ReportController::class, 'show']);

    Route::get('findByClient', [ProjectController::class, 'findByClient']);
    Route::post('project/store', [ProjectController::class, 'storeProject']);
    Route::post('project/addClient', [ProjectController::class, 'addClientToProject']);
    Route::post('project/add', [ProjectController::class, 'addUserToProject']);
    Route::post('project/add', [ProjectController::class, 'addUserToProject']);


    Route::post('storeProject', [ProjectController::class, 'storeProject']);

    //map
    Route::get('projects/map', [ProjectController::class, 'showProjectMap']);



});
Route::post('show-not-register',[ProjectController::class,'showNotRegister']);

Route::post('show-user', [ProfileController::class, 'showInformationUserForOthers']);
Route::post('other/projects', [ProjectController::class, 'showAllProjectForOthers']);


//map

Route::get('map', [\App\Http\Controllers\MapController::class, 'showAllProjectOnMap']);

Route::post('testAddGroup', [ChatController::class, 'testAddGroup']);
//before after photo
Route::post('beforeAfterPhoto', [ImageController::class, 'beforeAfterImage']);


Route::group(['prefix' => 'forgotPassword'], function () {
    Route::post('sendCode', [EmailController::class, 'sendEmailResetPassword']);
    Route::post('confirmCode', [ForgotPasswordController::class, 'confirmCode']);
    Route::put('{clientRole}/changePassword', [ForgotPasswordController::class, 'resetPassword']);
});


Route::post('images', [ImageController::class, 'upload']);

//Route::post('/completeInformation', [ProfileController::class, 'compeletUser'])->name('completeInformation');

/*Route::middleware('auth:sanctum')->prefix('/{clientRole}')->group(function (){
    Route::post('/completeInformation', [ProfileController::class, 'call'])->name('completeInformation');
    Route::post('/showInformation', [ProfileController::class, 'call'])->name('showInformation');
    Route::post('/updateInformation', [ProfileController::class, 'call'])->name('updateInformation');
});*/


Route::post('test', [ProjectController::class, 'testAddress']);

//home page
Route::get('siteInformation', [HomeController::class, 'getSiteInformation']);
Route::get('specialProject', [HomeController::class, 'getSpecialProject']);
Route::get('getTeam', [HomeController::class, 'getTeam']);
Route::get('countEntity', [HomeController::class, 'count']);
Route::post('map', [HomeController::class, 'getProjectOnMAp']);
Route::get('clientByJobTitle/{jobTitle}', [HomeController::class, 'getClientByJobTitle']);


//search project
Route::get('searchByCondition', [ProjectController::class, 'findByCondition']);
Route::get('searchByType', [ProjectController::class, 'findByType']);

Route::get('contractor/{id}', [GeneralContractorController::class, 'showbyId']);

//Route::post('comment', [CommentController::class, 'store']);
//Route::post('showComment', [CommentController::class, 'showById']);
Route::get('address', [\App\Http\Controllers\AddressController::class, 'searchAddressInMap']);



//Route::get('/payments', [PaymentController::class, 'index']);
/*Route::post('/pay', [PaymentController::class, 'pay'])->middleware('auth:sanctum');
Route::post('/verify', [PaymentController::class, 'verify']);*/

Route::post('charge', [PaymentController::class, 'charge']);
Route::get('success', [PaymentController::class, 'success']);
Route::get('error', [PaymentController::class, 'error'])->name('paypal.error');
Route::post('paypal', [PaymentController::class, 'paypal'])->middleware('auth:sanctum');

//plan
Route::post('showPlan', [\App\Http\Controllers\Admin\Structure\BillingPlanController::class, 'index']);

Route::get('showFAQ', [HomeController::class, 'indexForUser']);

Route::get('findByProject/{id}', [ImageController::class, 'findByProject']);
Route::get('findByReport/{id}', [ImageController::class, 'findByReport']);

Route::post('chat', [ChatController::class, 'index']);

Route::post('storeProject', [ProjectController::class, 'storeProject']);

Route::get('pdf', [PDFController::class, 'make']);

//Route::get('comment/show', [CommentController::class, 'show']);
Route::get('comment/show', [CommentController::class, 'show']);

Route::post('sendExternalEstimate', [EstimateController::class, 'sendExternalEstimate']);

Route::get('showJob', [JobController::class, 'show']);

//changePassword
//Route::post('changePassword', [\App\Http\Controllers\User\UserController::class, 'changePassword']);


Route::delete('/company/del/{name}',[ClientController::class, 'deleteCompanemaily']);
Route::delete('user/del/{name}',[ClientController::class, 'deleteUseremail']);
Route::get('client-list',[ProfileController::class,'ListClient']);
Route::get('client-list-email/{id}',[ProfileController::class,'searchUserByIndustry']);
//Route::get('shooooooooooooo', [InvoiceController::class, 'shooooooooooooo']);
Route::delete('remove-member/{groupId}/{UserId}',[ChatController::class,'removeMember'])->middleware(['auth:sanctum']);
Route::get('client/list',[ProfileController::class,'searchByClientsWithoutPaginate']);
